@@ -33,9 +33,10 @@
 #  define KCONFIGCORE_DEPRECATED_NO_EXPORT KCONFIGCORE_NO_EXPORT KCONFIGCORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCONFIGCORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCONFIGCORE_NO_DEPRECATED
+#    define KCONFIGCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
